==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="45"/>
        <source>Show playlist manipulation commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="58"/>
        <source>List all available playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="59"/>
        <source>Show playlist content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="60"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="61"/>
        <source>Clear playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="62"/>
        <source>Toggle playlist repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="63"/>
        <source>Toggle playlist shuffle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="64"/>
        <source>Show playlist options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="83"/>
        <location filename="../playlistoption.cpp" line="101"/>
        <location filename="../playlistoption.cpp" line="116"/>
        <source>Invalid playlist ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="95"/>
        <source>Invalid number of arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <source>Invalid track ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="45"/>
        <source>Show playlist manipulation commands</source>
        <translation>Zobrazit příkazy pro práci se seznamem skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="58"/>
        <source>List all available playlists</source>
        <translation>Vypsat všechny dostupné seznamy skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="59"/>
        <source>Show playlist content</source>
        <translation>Zobrazit obsah seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="60"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Přehrát stopu &lt;track&gt; ze seznamu &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="61"/>
        <source>Clear playlist</source>
        <translation>Vyprázdnit seznam skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="62"/>
        <source>Toggle playlist repeat</source>
        <translation>Přepnout opakování seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="63"/>
        <source>Toggle playlist shuffle</source>
        <translation>Přepnout zamíchání seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="64"/>
        <source>Show playlist options</source>
        <translation>Zobrazit možnosti seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="83"/>
        <location filename="../playlistoption.cpp" line="101"/>
        <location filename="../playlistoption.cpp" line="116"/>
        <source>Invalid playlist ID</source>
        <translation>Neplatné ID seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="95"/>
        <source>Invalid number of arguments</source>
        <translation>Špatný počet argumentů</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <source>Invalid track ID</source>
        <translation>Neplatné ID stopy</translation>
    </message>
</context>
</TS>
